@@ -46,6 +46,14 @@ public class NinaLanguageOptionCSharp implements NinaLanguageOption {
 		return "__this__.LOOKAHEAD_MARK();";
 	}
 
+	/* (non-Javadoc)
+	 * @see net.morilib.nina.NinaLanguageOption#getLookaheadMark()
+	 */
+	@Override
+	public String getLookaheadMarkInit() {
+		return "__this__.LOOKAHEAD_MARK_INIT();";
+	}
+
 	/* (non-Javadoc)
 	 * @see net.morilib.nina.NinaLanguageOption#getUnget()
 	 */
