@@ -143,6 +143,7 @@ public class NinaMatcherTest extends TestCase {
 	public void test0004() {
 		String s =
 				"#machine NFABuilder\n" +
+				"#option enableRegexByBackquote\n" +
 				" =======                                @*****\n" +
 				" =aaa  >----------------`a+`------------>aa  *\n" +
 				" ==^====                                **v***\n" +
@@ -172,6 +173,7 @@ public class NinaMatcherTest extends TestCase {
 	public void test0005() {
 		String s =
 				"#machine NFABuilder\n" +
+				"#option enableRegexByBackquote\n" +
 				" =======                                @*****\n" +
 				" =aaa  >-------------`(ab)+`------------>aa  *\n" +
 				" ==^====                                **v***\n" +
@@ -351,26 +353,28 @@ public class NinaMatcherTest extends TestCase {
 		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
 				new NinaSubautomata("a"),
 				new NinaConsoleStub());
-		mat(m, "\t:\r:\n:\u000b:\f:\r: ");
+//		mat(m, "\t:\r:\n:\u000b:\f:\r: ");
+		mat(m, "\t:\n: ");
 	}
 
 	public void test0018() {
-//		String s =
-//				"#machine DFABuilder\n" +
-//				"   /[\\p{Space}]--------\\  \n" +
-//				" ==^====             @*v***\n" +
-//				" =aaa  =             *aa  *\n" +
-//				" =v^====             **v***\n" +
-//				"  |\\---------------[\\S]/  \n" +
-//				"  |     ****  \n" +
-//				"  \\[\\S]->  *  \n" +
-//				"        ****  \n" +
-//				"";
-//		NinaPattern m;
-//
-//		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
-//				new NinaSubautomata("a"));
-//		mat(m, "\t:\r:\n:\u000b:\f:\r: ");
+		String s =
+				"#machine DFABuilder\n" +
+				"   /[\\p{Space}]--------\\  \n" +
+				" ==^====             @*v***\n" +
+				" =aaa  =             *aa  *\n" +
+				" =v^====             **v***\n" +
+				"  |\\---------------[\\S]/  \n" +
+				"  |     ****  \n" +
+				"  \\[\\S]->  *  \n" +
+				"        ****  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "\t:\r:\n:\u000b:\f:\r: ");
 	}
 
 	public void test0019() {
@@ -905,9 +909,9 @@ public class NinaMatcherTest extends TestCase {
 		String s =
 				"#machine NFABuilder\n" +
 				" =======                                @*****\n" +
-				" =aaa  >----------------'&'------------->aa  *\n" +
+				" =aaa  >----------------[\\[\\]\\&]-------->aa  *\n" +
 				" ==^====                                **v***\n" +
-				"   \\-------------------[\\[\\]&]------------/  \n" +
+				"   \\-------------------[\\[\\]\\&]-----------/  \n" +
 				"";
 		NinaPattern m;
 
@@ -919,6 +923,26 @@ public class NinaMatcherTest extends TestCase {
 		mat(m, "&[&]&");
 	}
 
+	public void test0122() {
+		String s =
+				"#machine NFABuilder\n" +
+				" =======                                @*****\n" +
+				" =aaa  >----------------[a-z&[^f]]------>aa  *\n" +
+				" ==^====                                **v***\n" +
+				"   \\-------------------[a-z&[^f]]---------/  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "a");  
+		mat(m, "abc");
+		mat(m, "abcde");
+		nmt(m, "f");
+		nmt(m, "abf");
+	}
+
 	public void test0131() {
 		String s =
 				"#machine NFABuilder\n" +
@@ -1031,6 +1055,7 @@ public class NinaMatcherTest extends TestCase {
 	public void test0144() {
 		String s =
 				"#machine NFABuilder\n" +
+				"#option enableRegexByBackquote\n" +
 				"#label lb1=`a+`\n" +
 				"#label lb2=`b+`\n" +
 				" =======     *****                      @*****\n" +
@@ -1251,4 +1276,89 @@ public class NinaMatcherTest extends TestCase {
 		mat(m, "bab");
 	}
 
+	public void test0191() {
+		String s =
+				"#machine DFABuilder\n" +
+				" *S***                      @*****\n" +
+				" *b  >-------~a~------------>aa  *\n" +
+				" **^**                      **v***\n" +
+				"   +---------~b~--------------+  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "a");
+		mat(m, "aba");
+		mat(m, " a b a ");
+		mat(m, "  a  b  a  ");
+		mat(m, "a  b  a");
+		mat(m, "ab  a");
+	}
+
+	public void test0201() {
+		String s =
+				"#machine NFABuilder\n" +
+				" =======                                @*****\n" +
+				" =aaa  >-------------/(ab)+/------------>aa  *\n" +
+				" ==^====                                **v***\n" +
+				"   \\-----------------/[c-z]/--------------/  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "ab");
+		mat(m, "ababcab");
+		mat(m, "abababcabab");
+		nmt(m, "");
+		nmt(m, "ababc");
+		nmt(m, "ababababc");
+		nmt(m, "abababacab");
+	}
+
+	public void test0211() {
+		String s =
+				"#machine NFABuilder\n" +
+				"#option disableTurnBySlash\n" +
+				" =======                                @*****\n" +
+				" =aaa  >-------------/ +/--------------->aa  *\n" +
+				" ==^====                                **v***\n" +
+				"   +----------------/[c-z]/---------------+  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "  ");
+		mat(m, "    c  ");
+		mat(m, "      c   ");
+		nmt(m, "");
+		nmt(m, "    c");
+	}
+
+	public void test0212() {
+		String s =
+				"#machine NFABuilder\n" +
+				"#option disableTurnBySlash\n" +
+				" =======                                @*****\n" +
+				" =aaa  >-------------/[a-z]+/----------->aa  *\n" +
+				" ==^====                                **v***\n" +
+				"   +----------------/ /-------------------+  \n" +
+				"";
+		NinaPattern m;
+
+		m = Nina.pattern("A", s, Collections.<String, String>emptyMap(),
+				new NinaSubautomata("a"),
+				new NinaConsoleStub());
+		mat(m, "aaaa");
+		mat(m, "aaaa aaa");
+		mat(m, "aaa aaa aaa");
+		nmt(m, "");
+		nmt(m, "aaaa ");
+	}
+
 }
